package com.dcsoft.system.vehicle.mapper;

import java.util.List;
import com.dcsoft.system.vehicle.domain.CarInfo;

/**
 * 车辆信息Mapper接口
 *
 * @author nichun
 * @date 2023-12-26
 */
public interface CarInfoMapper
{
    /**
     * 查询车辆信息
     *
     * @param customerId 车辆信息主键
     * @return 车辆信息
     */
    public CarInfo selectCarInfoByCustomerId(Long customerId);

    /**
     * 查询车辆信息列表
     *
     * @param carInfo 车辆信息
     * @return 车辆信息集合
     */
    public List<CarInfo> selectCarInfoList(CarInfo carInfo);

    /**
     * 新增车辆信息
     *
     * @param carInfo 车辆信息
     * @return 结果
     */
    public int insertCarInfo(CarInfo carInfo);

    /**
     * 修改车辆信息
     *
     * @param carInfo 车辆信息
     * @return 结果
     */
    public int updateCarInfo(CarInfo carInfo);

    /**
     * 删除车辆信息
     *
     * @param customerId 车辆信息主键
     * @return 结果
     */
    public int deleteCarInfoByCustomerId(Long customerId);

    /**
     * 批量删除车辆信息
     *
     * @param customerIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCarInfoByCustomerIds(Long[] customerIds);

    public CarInfo selectCarInfoByCarNo(String plate);
}
